==> udm-test-support-3.5.1-sources.jar: com/xebialabs/deployit/test/support/TestUtils.java <==
package com.xebialabs.deployit.test.support;

import static com.google.common.collect.Sets.newHashSet;

import java.io.File;
import java.io.IOException;
import java.net.URL;
import java.util.Arrays;
import java.util.Set;

import com.google.common.base.Joiner;
import com.google.common.io.Files;
import com.google.common.io.Resources;
import com.xebialabs.deployit.plugin.api.reflect.Descriptor;
import com.xebialabs.deployit.plugin.api.reflect.DescriptorRegistry;
import com.xebialabs.deployit.plugin.api.reflect.Type;
import com.xebialabs.deployit.plugin.api.udm.Application;
import com.xebialabs.deployit.plugin.api.udm.Container;
import com.xebialabs.deployit.plugin.api.udm.Deployable;
import com.xebialabs.deployit.plugin.api.udm.DeployedApplication;
import com.xebialabs.deployit.plugin.api.udm.DeploymentPackage;
import com.xebialabs.deployit.plugin.api.udm.Environment;
import com.xebialabs.deployit.plugin.api.udm.artifact.SourceArtifact;
import com.xebialabs.deployit.plugin.jee.artifact.Ear;
import com.xebialabs.deployit.plugin.jee.artifact.EjbJar;
import com.xebialabs.deployit.plugin.jee.artifact.War;
import com.xebialabs.overthere.local.LocalFile;

public class TestUtils {

    @SuppressWarnings("unchecked")
    public static <T> T newInstance(String type) {
        Descriptor descriptor = DescriptorRegistry.getDescriptor(type);
        if (descriptor == null) {
            throw new RuntimeException("Cannot instantiate unknown type");

        }
        return (T) descriptor.newInstance();
    }

    @SuppressWarnings("unchecked")
    public static <T> T newInstance(Class<T> clazz) {
        return (T) newInstance(Type.valueOf(clazz).toString());
    }

    public static String id(String... names) {
        return Joiner.on('/').join(names);
    }

    public static DeploymentPackage createDeploymentPackage(Deployable... deployables) {
        return createDeploymentPackage("1.0", deployables);
    }

    public static DeploymentPackage createDeploymentPackage(String version, Deployable... deployables) {
        Application app = newInstance(Application.class);
        app.setId(id("Applications", "Test"));
        DeploymentPackage pkg = newInstance(DeploymentPackage.class);
        pkg.setId(id(pkg.getId(), version));
        pkg.setApplication(app);

        for (Deployable deployable : deployables) {
            deployable.setId(id(app.getId(), deployable.getId()));
            pkg.addDeployable(deployable);
        }

        return pkg;
    }

    public static Environment createEnvironment(Container... containers) {
        Environment env = newInstance(Environment.class);
        env.setId(id("Environments", "JUnit"));
        Set<Container> containerSet = newHashSet();
        containerSet.addAll(Arrays.asList(containers));
        env.setMembers(containerSet);
        return env;
    }

    public static DeployedApplication createDeployedApplication(DeploymentPackage pkg, Environment env) {
        DeployedApplication deployedApp = newInstance(DeployedApplication.class);
        deployedApp.setVersion(pkg);
        deployedApp.setEnvironment(env);
        return deployedApp;
    }

    public static Ear newEar(String name, String version, String classpathResource, File workingFolder) throws IOException {
        return newEar(name, version, classpathResource, "jee.Ear", workingFolder);
    }

    public static Ear newEar(String name, String version, String classpathResource, String type, File workingFolder) throws IOException {
        return createArtifact(name, version, classpathResource, type, workingFolder, Ear.class);
    }

    public static <T extends SourceArtifact> T createArtifact(String name, String version, String classpathResource, String type, File workingFolder, Class<T> clazz)
            throws IOException {
        @SuppressWarnings("unchecked")
        T artifact = (T) newInstance(type);
        artifact.setId(id("Applications", "Test", version, name));
        File artifactFile = new File(workingFolder, artifact.getName());
        artifactFile.createNewFile();
        URL artifactURL = Thread.currentThread().getContextClassLoader().getResource(classpathResource);
        Files.copy(Resources.newInputStreamSupplier(artifactURL), artifactFile);
        artifact.setFile(LocalFile.valueOf(artifactFile));
        return artifact;

    }

    public static War newWar(String name, String version, String classpathResource, String type, File workingFolder) throws IOException {
        return createArtifact(name, version, classpathResource, type, workingFolder, War.class);
    }

    public static EjbJar newEjbJar(String name, String version, String classpathResource, String type, File workingFolder) throws IOException {
        return createArtifact(name, version, classpathResource, type, workingFolder, EjbJar.class);
    }
}

==> udm-test-support-3.6.0-sources.jar: com/xebialabs/deployit/test/support/TestUtils.java <==
package com.xebialabs.deployit.test.support;

import static com.google.common.collect.Sets.newHashSet;

import java.io.File;
import java.io.IOException;
import java.net.URISyntaxException;
import java.net.URL;
import java.util.Arrays;
import java.util.Set;

import com.google.common.base.Joiner;
import com.google.common.io.Files;
import com.google.common.io.Resources;
import com.xebialabs.deployit.plugin.api.reflect.Descriptor;
import com.xebialabs.deployit.plugin.api.reflect.DescriptorRegistry;
import com.xebialabs.deployit.plugin.api.reflect.Type;
import com.xebialabs.deployit.plugin.api.udm.Application;
import com.xebialabs.deployit.plugin.api.udm.Container;
import com.xebialabs.deployit.plugin.api.udm.Deployable;
import com.xebialabs.deployit.plugin.api.udm.DeployedApplication;
import com.xebialabs.deployit.plugin.api.udm.DeploymentPackage;
import com.xebialabs.deployit.plugin.api.udm.Environment;
import com.xebialabs.deployit.plugin.api.udm.artifact.SourceArtifact;
import com.xebialabs.deployit.plugin.jee.artifact.Ear;
import com.xebialabs.deployit.plugin.jee.artifact.EjbJar;
import com.xebialabs.deployit.plugin.jee.artifact.War;
import com.xebialabs.overthere.local.LocalFile;

public class TestUtils {

    @SuppressWarnings("unchecked")
    public static <T> T newInstance(String type) {
        Descriptor descriptor = DescriptorRegistry.getDescriptor(type);
        if (descriptor == null) {
            throw new RuntimeException("Cannot instantiate unknown type");

        }
        return (T) descriptor.newInstance();
    }

    @SuppressWarnings("unchecked")
    public static <T> T newInstance(Class<T> clazz) {
        return (T) newInstance(Type.valueOf(clazz).toString());
    }

    public static String id(String... names) {
        return Joiner.on('/').join(names);
    }

    public static DeploymentPackage createDeploymentPackage(Deployable... deployables) {
        return createDeploymentPackage("1.0", deployables);
    }

    public static DeploymentPackage createDeploymentPackage(String version, Deployable... deployables) {
        Application app = newInstance(Application.class);
        app.setId(id("Applications", "Test"));
        DeploymentPackage pkg = newInstance(DeploymentPackage.class);
        pkg.setId(id(pkg.getId(), version));
        pkg.setApplication(app);

        for (Deployable deployable : deployables) {
            deployable.setId(id(app.getId(), deployable.getId()));
            pkg.addDeployable(deployable);
        }

        return pkg;
    }

    public static Environment createEnvironment(Container... containers) {
        Environment env = newInstance(Environment.class);
        env.setId(id("Environments", "JUnit"));
        Set<Container> containerSet = newHashSet();
        containerSet.addAll(Arrays.asList(containers));
        env.setMembers(containerSet);
        return env;
    }

    public static DeployedApplication createDeployedApplication(DeploymentPackage pkg, Environment env) {
        DeployedApplication deployedApp = newInstance(DeployedApplication.class);
        deployedApp.setVersion(pkg);
        deployedApp.setEnvironment(env);
        return deployedApp;
    }

    public static Ear newEar(String name, String version, String classpathResource, File workingFolder) throws IOException {
        return newEar(name, version, classpathResource, "jee.Ear", workingFolder);
    }

    public static Ear newEar(String name, String version, String classpathResource, String type, File workingFolder) throws IOException {
        return createArtifact(name, version, classpathResource, type, workingFolder);
    }

    public static <T extends SourceArtifact> T createArtifact(String name, String version, String classpathResource, String type, File workingFolder)
            throws IOException {
        @SuppressWarnings("unchecked")
        T artifact = (T) newInstance(type);
        artifact.setId(id("Applications", "Test", version, name));
        URL artifactURL = Thread.currentThread().getContextClassLoader().getResource(classpathResource);
        File artifactFile = new File(workingFolder, artifact.getName());
        artifactFile.createNewFile();
        Files.copy(Resources.newInputStreamSupplier(artifactURL), artifactFile);
        artifact.setFile(LocalFile.valueOf(artifactFile));
        return artifact;
    }

	public static <T extends SourceArtifact> T createArtifactWithoutCopy(String name, String version, String classpathResource, String type, File workingFolder)
	        throws IOException, URISyntaxException {
        @SuppressWarnings("unchecked")
        T artifact = (T) newInstance(type);
        artifact.setId(id("Applications", "Test", version, name));
		URL artifactURL = Thread.currentThread().getContextClassLoader().getResource(classpathResource);
		artifact.setFile(LocalFile.valueOf(new File(artifactURL.toURI().getPath())));
		return artifact;
	}

    public static War newWar(String name, String version, String classpathResource, String type, File workingFolder) throws IOException {
        return createArtifact(name, version, classpathResource, type, workingFolder);
    }

    public static EjbJar newEjbJar(String name, String version, String classpathResource, String type, File workingFolder) throws IOException {
        return createArtifact(name, version, classpathResource, type, workingFolder);
    }
}
